"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/logging.ts
var logging_exports = {};
__export(logging_exports, {
  createLogger: () => createLogger,
  maskTokens: () => maskTokens,
  requestLogger: () => requestLogger
});
module.exports = __toCommonJS(logging_exports);

// src/logging/mask-tokens.ts
var maskTokens = (output) => {
  return output.replace(/sm_(pat|aat|sat)_[0-9a-zA-Z]+/g, "***");
};

// src/logging/logger.ts
function createLogger(options = {}) {
  const { level = "warn", prefix = "" } = options;
  const logLevels = {
    debug: 0,
    info: 1,
    warn: 2,
    error: 3,
    none: 4
  };
  const currentLevelValue = logLevels[level];
  const formatArgs = (args) => {
    if (args.length === 0 || args.every((arg) => arg === void 0 || arg === null)) {
      return "";
    }
    const formatted = args.map((arg) => {
      if (arg instanceof Error) {
        return `
${arg.stack || arg.message}`;
      }
      if (typeof arg === "object" && arg !== null) {
        return `
${JSON.stringify(arg, null, 2)}`;
      }
      return ` ${String(arg)}`;
    }).join("");
    return `, args:${formatted}`;
  };
  const shouldLog = (level2) => {
    return logLevels[level2] >= currentLevelValue;
  };
  return {
    debug: (message, ...args) => {
      if (shouldLog("debug")) {
        console.debug(`\x1B[32m${prefix}[DEBUG] ${maskTokens(message)}${maskTokens(formatArgs(args))}\x1B[0m`);
      }
    },
    info: (message, ...args) => {
      if (shouldLog("info")) {
        console.info(`\x1B[34m${prefix}[INFO] ${maskTokens(message)}${maskTokens(formatArgs(args))}\x1B[0m`);
      }
    },
    warn: (message, ...args) => {
      if (shouldLog("warn")) {
        console.warn(`\x1B[33m${prefix}[WARN] ${maskTokens(message)}${maskTokens(formatArgs(args))}\x1B[0m`);
      }
    },
    error: (message, ...args) => {
      if (shouldLog("error")) {
        console.error(`\x1B[31m${prefix}[ERROR] ${maskTokens(message)}${maskTokens(formatArgs(args))}\x1B[0m`);
      }
    }
  };
}
var logger = createLogger();

// src/string.ts
function truncate(value, maxLength) {
  if (value.length <= maxLength) {
    return value;
  }
  return `${value.slice(0, maxLength)}...`;
}

// src/logging/request-logger.ts
var WARNING_THRESHOLD = 500;
var TRUNCATE_LENGTH = 50;
function requestLogger(logger2, name, fn) {
  return async (...args) => {
    const start = Date.now();
    try {
      return await fn(...args);
    } finally {
      const end = Date.now();
      const duration = end - start;
      const body = extractInfoFromBody(args[1]?.body ?? "{}");
      const message = `${name} path: ${args[0]}, took ${formatDuration(duration)}`;
      if (duration > WARNING_THRESHOLD) {
        logger2.warn(message, body);
      } else {
        logger2.info(message, body);
      }
    }
  };
}
function formatDuration(duration) {
  return duration < 1e3 ? `${duration}ms` : `${(duration / 1e3).toFixed(3)}s`;
}
function extractInfoFromBody(body) {
  try {
    const parsedBody = typeof body === "string" ? JSON.parse(body) : body;
    if (parsedBody === null || parsedBody === void 0 || Object.keys(parsedBody).length === 0) {
      return null;
    }
    const dataToKeep = {};
    if ("query" in parsedBody) {
      dataToKeep.query = truncate(parsedBody.query, TRUNCATE_LENGTH);
    }
    if ("variables" in parsedBody) {
      dataToKeep.variables = truncate(JSON.stringify(parsedBody.variables), TRUNCATE_LENGTH);
    }
    if ("operationName" in parsedBody) {
      dataToKeep.operationName = truncate(parsedBody.operationName, TRUNCATE_LENGTH);
    }
    if (Object.keys(dataToKeep).length > 0) {
      return JSON.stringify(dataToKeep);
    }
    return truncate(JSON.stringify(parsedBody || "{}"), TRUNCATE_LENGTH);
  } catch {
    return "{}";
  }
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  createLogger,
  maskTokens,
  requestLogger
});
//# sourceMappingURL=logging.cjs.map